@@ -1,6 +1,6 @@
 pub use buf_reader::BufReader;
 pub mod buf_reader;
-
 pub use string::String;
 pub mod string;
-
+pub mod transcribe;
+pub use transcribe::Transcribe;
